@@ -1,15 +1,19 @@
-from .data_service.base_data import BaseDataSource
 from .meta_data.data_key_words import DATA_KEY_WORDS
 
 
 def get_benchmark_code(benchmark_name: str) -> str:
-    """get benchmark code by benchmark name
+    """
+    get benchmark code by benchmark name
 
-    Args:
+    Parameters
+    ----------
+    benchmark_name : str
         benchmar_name (str): benchmark Name
 
-    Returns:
-        str: benchmark code
+    Returns
+    -------
+    str
+        benchmark code
     """
     benchmark_name == benchmark_name.strip()
     if benchmark_name == '沪深300':
@@ -28,10 +32,15 @@ def get_benchmark_code(benchmark_name: str) -> str:
 def get_universe_code(universe_name: str) -> str:
     """get univese code by universe name
 
-    Args:
-        universe_name (str): universe name
-    Returns:
-        str: universe code
+    Parameters
+    ----------
+    universe_name : str
+        universe name
+
+    Returns
+    -------
+    str
+        universe code
     """
     universe_name = universe_name.strip()
     if universe_name == '沪深300':
@@ -46,17 +55,6 @@ def get_universe_code(universe_name: str) -> str:
         return 'zzqz'
 
 
-def get_peroid_tuple(period_str: str) -> tuple:
-    """get periods list by period string like '1 5 10'
-
-    Args:
-        period_str (str): period string
-
-    Returns:
-        tuple: periods tuple
-    """
-    return tuple(map(int, period_str.split(' ')))
-
 def load_data_key_words() -> list:
     """load data keywords
 
@@ -66,8 +64,3 @@ def load_data_key_words() -> list:
         data keywords
     """
     return DATA_KEY_WORDS
-
-
-def get_all_stocks(data_source: BaseDataSource):
-
-    return list(data_source.QUOTE.columns)
